#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 djinn-lib
version:              0.0.1.3
visibility:           public
id:                   djinn-lib-0.0.1.3-38U0fPX8b478U0KyJLpJUn
key:                  djinn-lib-0.0.1.3-38U0fPX8b478U0KyJLpJUn
license:              BSD-3-Clause
maintainer:           trupill@gmail.com
author:               Lennart Augustsson
homepage:             http://www.augustsson.net/Darcs/Djinn/
synopsis:
    Generate Haskell code from a type. Library extracted from djinn package.

description:
    Djinn uses an theorem prover for intuitionistic propositional logic
    to generate a Haskell expression when given a type.
    This is a library extracted from Djinn sources.

category:             Language
abi:                  62e0db8e98ab174736118e066a9fdfd1
exposed:              True
exposed-modules:      Djinn.HCheck Djinn.HTypes Djinn.LJT Djinn.LJTFormula
import-dirs:          /usr/lib/ghc-8.10.5/site-local/djinn-lib-0.0.1.3
library-dirs:         /usr/lib/ghc-8.10.5/site-local/djinn-lib-0.0.1.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/i386-linux-ghc-8.10.5/djinn-lib-0.0.1.3
hs-libraries:         HSdjinn-lib-0.0.1.3-38U0fPX8b478U0KyJLpJUn
depends:
    base-4.14.2.0 containers-0.6.4.1 mtl-2.2.2 pretty-1.1.3.6

haddock-interfaces:   /usr/share/doc/haskell-djinn-lib/html/djinn-lib.haddock
haddock-html:         /usr/share/doc/haskell-djinn-lib/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

